@@ -1,4 +1,4 @@
-## Copyright (C) 2012 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2012-2016 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -220,7 +220,7 @@ function [p_res, objf, cvg, outp] = __lm_feasible__ (f, pin, hook)
         ## below previously)
         dch = (dca_new_id(:, bidx_old_id) - ...
                dca_old_id(:, bidx_old_id)) * ...
-            lb(old_l_idx);
+            lb(old_l_idx, 1);
       
         y = df - old_df - dch;
 
