@@ -1,7 +1,7 @@
 ## Copyright (C) 1992-1994 Richard Shrager
 ## Copyright (C) 1992-1994 Arthur Jutan
 ## Copyright (C) 1992-1994 Ray Muzic
-## Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2010-2016 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -151,6 +151,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
   nc_idx = false (n_lcstr + n_gencstr, 1); # none of all constraints
   gc_idx = cat (1, false (n_lcstr, 1), true (n_gencstr, 1)); # gen. constr.
   lc_idx = ~gc_idx;
+  lambda = t_lambda = zeros (n_lcstr + n_gencstr, 1); # for returning lambda
 
   if (([stop, outp.user_interaction] = ...
        __do_user_interaction__ (user_interaction, p,
@@ -252,6 +253,9 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
         c_unbinding(c_act) = ridx; # constraints unselected binding
         c_nonbinding = c_act & ~(c_binding | c_unbinding); # constraints
                                 # selected non-binding
+        ## for returning lambda
+        lambda = t_lambda;
+        lambda(c_binding) = lb;
       else
         ## chg is the Levenberg/Marquardt step
         chg = tp1;
@@ -392,7 +396,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
               endif
               if (unsuccessful_exchange)
                 ## It probably doesn't look good now; this desperate
-                ## last attempt is not in the original algortithm, since
+                ## last attempt is not in the original algorithm, since
                 ## that didn't account for equality constraints.
                 ptp1 = (pprev + ptp1) / 2;
               else
@@ -410,7 +414,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
           endif
           if (~nt_nosuc)
             deb_printf (testing, "regaining successful, converged with %i iterations:\n", ...
-            nt_niter_start - nt_niter);
+                        nt_niter_start - nt_niter);
             deb_printf (testing, "%e\n", ptp2);
           endif
           lim = lim - 1;
@@ -426,13 +430,14 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
         chg(idx) = min(max(chg(idx),-limit),limit);
         if (verbose && any(ochg ~= chg))
           disp(['Change in parameter(s): ', ...
-                sprintf("%d ",find(ochg ~= chg)), "maximal fractional stepwidth enforced"]);
+                sprintf("%d ",find(ochg ~= chg)), ...
+                "maximal fractional stepwidth enforced"]);
         endif
       endif
       aprec = pprec .* (abs (pbest) + add_pprec);
       ## ss=scalar sum of squares=sum((wt.*f)^2).
       if (any(abs(chg) > 0.1*aprec))#---  # only worth evaluating
-                                # function if there is some non-miniscule
+                                #function if there is some non-miniscule
                                 # change
         ## In the code of the outer loop before the inner loop pbest is
         ## actually identical to p, since once they deviate, the outer
@@ -463,7 +468,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
         endif
         ss = r.' * r;
         deb_printf (testing, "tried parameters:\n");
-        deb_printf (testing, "%.16e\n", p); 
+        deb_printf (testing, "%.16e\n", p);
         deb_printf (testing, "sbest: %.16e\n", sbest);
         deb_printf (testing, "sgoal: %.16e\n", sgoal);
         deb_printf (testing, "   ss: %.16e\n", ss);
@@ -480,7 +485,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
         skipped = true;
         break;
       endif                          #---
-    endfor
+     endfor
     ## printf ("epsL no.: %i\n", jjj); # for testing
     epsLlast = epsL;
 
@@ -527,6 +532,7 @@ function [p, resid, cvg, outp] = __lm_svd__ (F, pin, hook)
   p = pbest;
   resid = fbest;
   outp.niter = iter;
+  outp.lambda = lambda;
 
   if (([stop, outp.user_interaction] = ...
        __do_user_interaction__ (user_interaction, pbest,
