@@ -1,5 +1,5 @@
 ## Copyright (C) 2008, 2009 VZLU Prague, a.s.
-## Copyright (C) 2010 Olaf Till <i7tiol@t-online.de>
+## Copyright (C) 2010-2016 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -80,7 +80,7 @@
 
 ## Author: Jaroslav Hajek <highegg@gmail.com>
 
-## PKG_ADD: __all_opts__ ("vfzero");
+## PKG_ADD: [~] = __all_opts__ ("vfzero");
 
 function [x, fval, info, output] = vfzero (fun, x0, options = struct ())
 
